pub struct DidKey;Expand description
DidKey provides a type for implementing did:key operation and
resolution methods.
Implementations
Sourceimpl DidKey
impl DidKey
Sourcepub fn create(op: &impl DidOperator, options: CreateOptions) -> Result<Document>
pub fn create(op: &impl DidOperator, options: CreateOptions) -> Result<Document>
Create a DID Document from the verifying key provided by DidOperator.
Errors
Returns an error if the supplied verifying key is not found or not a valid format.