pub struct Options {
pub accept: Option<ContentType>,
pub additional: Option<HashMap<String, Metadata>>,
}Expand description
Used to pass addtional values to a resolve and dereference methods. Any
properties used should be registered in the DID Specification Registries.
The accept property is common to all resolver implementations. It is used
by users to specify the Media Type when calling the resolve_representation
method. For example:
{
"accept": "application/did+ld+json"
}Fields
accept: Option<ContentType>accept resolution option.
additional: Option<HashMap<String, Metadata>>Additional options.